/* Generated by wayland-scanner 1.24.0 */

#ifndef WP_PRIMARY_SELECTION_UNSTABLE_V1_ENUM_PROTOCOL_H
#define WP_PRIMARY_SELECTION_UNSTABLE_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifdef  __cplusplus
}
#endif

#endif
