/* Generated by wayland-scanner 1.24.0 */

#ifndef TEARING_CONTROL_V1_ENUM_PROTOCOL_H
#define TEARING_CONTROL_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef WP_TEARING_CONTROL_MANAGER_V1_ERROR_ENUM
#define WP_TEARING_CONTROL_MANAGER_V1_ERROR_ENUM
enum wp_tearing_control_manager_v1_error {
	/**
	 * the surface already has a tearing object associated
	 */
	WP_TEARING_CONTROL_MANAGER_V1_ERROR_TEARING_CONTROL_EXISTS = 0,
};
#endif /* WP_TEARING_CONTROL_MANAGER_V1_ERROR_ENUM */

#ifndef WP_TEARING_CONTROL_V1_PRESENTATION_HINT_ENUM
#define WP_TEARING_CONTROL_V1_PRESENTATION_HINT_ENUM
/**
 * @ingroup iface_wp_tearing_control_v1
 * presentation hint values
 *
 * This enum provides information for if submitted frames from the client
 * may be presented with tearing.
 */
enum wp_tearing_control_v1_presentation_hint {
	/**
	 * tearing-free presentation
	 *
	 * The content of this surface is meant to be synchronized to the
	 * vertical blanking period. This should not result in visible
	 * tearing and may result in a delay before a surface commit is
	 * presented.
	 */
	WP_TEARING_CONTROL_V1_PRESENTATION_HINT_VSYNC = 0,
	/**
	 * asynchronous presentation
	 *
	 * The content of this surface is meant to be presented with
	 * minimal latency and tearing is acceptable.
	 */
	WP_TEARING_CONTROL_V1_PRESENTATION_HINT_ASYNC = 1,
};
#endif /* WP_TEARING_CONTROL_V1_PRESENTATION_HINT_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
