/* Generated by wayland-scanner 1.24.0 */

#ifndef CONTENT_TYPE_V1_ENUM_PROTOCOL_H
#define CONTENT_TYPE_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef WP_CONTENT_TYPE_MANAGER_V1_ERROR_ENUM
#define WP_CONTENT_TYPE_MANAGER_V1_ERROR_ENUM
enum wp_content_type_manager_v1_error {
	/**
	 * wl_surface already has a content type object
	 */
	WP_CONTENT_TYPE_MANAGER_V1_ERROR_ALREADY_CONSTRUCTED = 0,
};
#endif /* WP_CONTENT_TYPE_MANAGER_V1_ERROR_ENUM */

#ifndef WP_CONTENT_TYPE_V1_TYPE_ENUM
#define WP_CONTENT_TYPE_V1_TYPE_ENUM
/**
 * @ingroup iface_wp_content_type_v1
 * possible content types
 *
 * These values describe the available content types for a surface.
 */
enum wp_content_type_v1_type {
	/**
	 * no content type applies
	 *
	 * The content type none means that either the application has no
	 * data about the content type, or that the content doesn't fit
	 * into one of the other categories.
	 */
	WP_CONTENT_TYPE_V1_TYPE_NONE = 0,
	/**
	 * photo content type
	 *
	 * The content type photo describes content derived from digital
	 * still pictures and may be presented with minimal processing.
	 */
	WP_CONTENT_TYPE_V1_TYPE_PHOTO = 1,
	/**
	 * video content type
	 *
	 * The content type video describes a video or animation and may
	 * be presented with more accurate timing to avoid stutter. Where
	 * scaling is needed, scaling methods more appropriate for video
	 * may be used.
	 */
	WP_CONTENT_TYPE_V1_TYPE_VIDEO = 2,
	/**
	 * game content type
	 *
	 * The content type game describes a running game. Its content
	 * may be presented with reduced latency.
	 */
	WP_CONTENT_TYPE_V1_TYPE_GAME = 3,
};
#endif /* WP_CONTENT_TYPE_V1_TYPE_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
