/* Generated by wayland-scanner 1.24.0 */

#ifndef XDG_DIALOG_V1_ENUM_PROTOCOL_H
#define XDG_DIALOG_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef XDG_WM_DIALOG_V1_ERROR_ENUM
#define XDG_WM_DIALOG_V1_ERROR_ENUM
enum xdg_wm_dialog_v1_error {
	/**
	 * the xdg_toplevel object has already been used to create a xdg_dialog_v1
	 */
	XDG_WM_DIALOG_V1_ERROR_ALREADY_USED = 0,
};
#endif /* XDG_WM_DIALOG_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
