/* Generated by wayland-scanner 1.24.0 */

#ifndef XDG_ACTIVATION_V1_ENUM_PROTOCOL_H
#define XDG_ACTIVATION_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef XDG_ACTIVATION_TOKEN_V1_ERROR_ENUM
#define XDG_ACTIVATION_TOKEN_V1_ERROR_ENUM
enum xdg_activation_token_v1_error {
	/**
	 * The token has already been used previously
	 */
	XDG_ACTIVATION_TOKEN_V1_ERROR_ALREADY_USED = 0,
};
#endif /* XDG_ACTIVATION_TOKEN_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
