/* Generated by wayland-scanner 1.24.0 */

#ifndef SECURITY_CONTEXT_V1_ENUM_PROTOCOL_H
#define SECURITY_CONTEXT_V1_ENUM_PROTOCOL_H

#ifdef  __cplusplus
extern "C" {
#endif

#ifndef WP_SECURITY_CONTEXT_MANAGER_V1_ERROR_ENUM
#define WP_SECURITY_CONTEXT_MANAGER_V1_ERROR_ENUM
enum wp_security_context_manager_v1_error {
	/**
	 * listening socket FD is invalid
	 */
	WP_SECURITY_CONTEXT_MANAGER_V1_ERROR_INVALID_LISTEN_FD = 1,
	/**
	 * nested security contexts are forbidden
	 */
	WP_SECURITY_CONTEXT_MANAGER_V1_ERROR_NESTED = 2,
};
#endif /* WP_SECURITY_CONTEXT_MANAGER_V1_ERROR_ENUM */

#ifndef WP_SECURITY_CONTEXT_V1_ERROR_ENUM
#define WP_SECURITY_CONTEXT_V1_ERROR_ENUM
enum wp_security_context_v1_error {
	/**
	 * security context has already been committed
	 */
	WP_SECURITY_CONTEXT_V1_ERROR_ALREADY_USED = 1,
	/**
	 * metadata has already been set
	 */
	WP_SECURITY_CONTEXT_V1_ERROR_ALREADY_SET = 2,
	/**
	 * metadata is invalid
	 */
	WP_SECURITY_CONTEXT_V1_ERROR_INVALID_METADATA = 3,
};
#endif /* WP_SECURITY_CONTEXT_V1_ERROR_ENUM */

#ifdef  __cplusplus
}
#endif

#endif
